package core.schedules;

import core.entities.timemanager.AbstractSchedule;
import core.repositories.timemanager.TaskgroupRepository;
import core.services.TaskScheduleService;
import core.services.TaskgroupService;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.jdbc.Sql;
import org.springframework.test.context.jdbc.SqlGroup;

import javax.persistence.EntityManager;
import javax.transaction.Transactional;

import java.util.List;

import static org.hibernate.validator.internal.util.Contracts.assertTrue;
import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

@SpringBootTest
@Transactional
public class ScheduleServiceTest {


    @Autowired
    private EntityManager entityManager;

    @Autowired private TaskScheduleService taskScheduleService;

    private static final String username = "Testuser1";
    private static final String username2 = "Testuser2";

    @Test
    @SqlGroup({
            @Sql("classpath:taskgroupRepositoryTestEntries.sql"),
            @Sql("classpath:taskRepositoryEntries.sql"),
            @Sql("classpath:basicScheduleEntries.sql")
    })
    void getAllSchedulesOfUser() {
        assertEquals(0, taskScheduleService.getAllSchedulesOfUser(username2).size());

        List<AbstractSchedule> result_1 = taskScheduleService.getAllSchedulesOfUser(username);
        assertEquals(2, result_1.size());
        assertTrue(result_1.contains(entityManager.find(AbstractSchedule.class, 1L)));
        assertTrue(result_1.contains(entityManager.find(AbstractSchedule.class, 2L)));
    }
}
